@@ -4,15 +4,12 @@ package Business::UPS::Tracking::Commandline;
 use utf8;
 use 5.0100;
 
-use metaclass (
-    metaclass   => "Moose::Meta::Class",
-    error_class => "Business::UPS::Tracking::Exception",
-);
 use Moose;
-
 extends qw(Business::UPS::Tracking::Request);
 with qw(MooseX::Getopt Business::UPS::Tracking::Role::Base);
 
+__PACKAGE__->meta->error_class("Business::UPS::Tracking::Exception");
+
 our $VERSION = $Business::UPS::Tracking::VERISON;
 
 =encoding utf8
