@@ -4,12 +4,9 @@ package Business::UPS::Tracking::Shipment::Freight;
 use utf8;
 use 5.0100;
 
-use metaclass (
-    metaclass   => "Moose::Meta::Class",
-    error_class => "Business::UPS::Tracking::Exception",
-);
 use Moose;
 extends 'Business::UPS::Tracking::Shipment';
+__PACKAGE__->meta->error_class("Business::UPS::Tracking::Exception");
 
 our $VERSION = $Business::UPS::Tracking::VERISON;
 
